@@ -137,6 +137,25 @@ class Server(object):
         """
         del self[dbname]
         
+    #TODO: maintain list of replications
+    def replicate(self, source, target, continuous=False):
+        """
+        simple handler for replication
+        
+        @param source: str, URI or dbname of the source
+        @param target: str, URI or dbname of the target
+        @param continuous: boolean, default is False, set the type of replication
+        
+        More info about replication here : 
+        http://wiki.apache.org/couchdb/Replication
+        
+        """
+        self.res.post('/_replicate', payload={
+            "source": source,
+            "target": target,
+            "continuous": continuous
+        })
+        
     def next_uuid(self, count=None):
         """
         return an available uuid from couchdbkit
@@ -168,7 +187,7 @@ class Server(object):
     def __getitem__(self, dbname):
         if dbname in self:
             return Database(self, dbname)
-        raise ResourceNotFound
+        raise ResourceNotFound()
         
     def __delitem__(self, dbname):
         return self.res.delete('/%s/' % url_quote(dbname, safe=":"))
@@ -645,7 +664,11 @@ class Database(object):
         docid = self.escape_docid(doc['_id'])
         name = url_quote(name, safe="")
         
-        return self.res(docid).delete(name, rev=doc['_rev'])
+        res = self.res(docid).delete(name, rev=doc['_rev'])
+        if res['ok']:
+            doc.update({ '_rev': res['rev']})
+        return res['ok']
+        
 
     def fetch_attachment(self, id_or_doc, name, stream=False, 
             stream_size=16384):
@@ -847,7 +870,7 @@ class ViewResults(object):
         else:
             params['key'] = key
         
-        return ViewResults(self.view, params)
+        return ViewResults(self.view, **params)
         
     def __iter__(self):
         return self.iterator()
