@@ -36,9 +36,9 @@ __all__ = ['ReservedWordError', 'ALLOWED_PROPERTY_TYPES', 'DocumentSchema',
         'SchemaProperties', 'DocumentBase', 'QueryMixin', 'AttachmentMixin', 
         'Document', 'StaticDocument', 'valid_id']
 
-_RESERVED_WORDS = ['_id', '_rev', '$schema', 'type']
+_RESERVED_WORDS = ['_id', '_rev', '$schema']
 
-_NODOC_WORDS = ['doc_type', 'type']
+_NODOC_WORDS = ['doc_type']
 
 def check_reserved_words(attr_name):
     if attr_name in _RESERVED_WORDS:
@@ -541,7 +541,7 @@ class AttachmentMixin(object):
         """
         if not hasattr(self, '_db'):
             raise TypeError("doc database required to save document")
-        return self.__class__._db.put_attachment(self, content, name=name,
+        return self.__class__._db.put_attachment(self._doc, content, name=name,
             content_type=content_type, content_length=content_length)
 
     def delete_attachment(self, name):
@@ -553,7 +553,7 @@ class AttachmentMixin(object):
         """
         if not hasattr(self, '_db'):
             raise TypeError("doc database required to save document")
-        return self.__class__._db.delete_attachment(self, name)
+        return self.__class__._db.delete_attachment(self._doc, name)
 
     def fetch_attachment(self, name, stream=False, stream_size=16384):
         """ get attachment in a adocument
@@ -566,7 +566,7 @@ class AttachmentMixin(object):
         """
         if not hasattr(self, '_db'):
             raise TypeError("doc database required to save document")
-        return self.__class__._db.fetch_attachment(self, name, stream=stream,
+        return self.__class__._db.fetch_attachment(self._doc, name, stream=stream,
             stream_size=stream_size)
         
         
